@@ -2,6 +2,10 @@ from pathlib import Path
 
 
 def create_dir(dir_name: str):
+    """
+    :param dir_name: create dir use dir name
+    :return: None
+    """
     Path(dir_name).mkdir(
         parents=True,
         exist_ok=True
